@@ -9,7 +9,7 @@ _here = pathlib.Path(__file__).parent
 
 # load default theory
 default_card = {}
-with open(_here / "theory_template.yaml") as f:
+with open(_here / "theory_template.yaml", encoding="utf-8") as f:
     default_card = yaml.safe_load(f)
 default_card = dict(sorted(default_card.items()))
 
